==> guikachu_1.0.1.orig.tar.gz: guikachu-1.0.1/src/form-editor/graffiti-prop.cc <==
//$Id: graffiti-prop.cc,v 1.9 2001/11/03 01:30:45 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "graffiti-prop.h"


#include "config.h"
#include <libgnome/libgnome.h>

#include "widget-prop.h"

#include "widgets/propertytable.h"

using namespace Guikachu::GUI::FormEditor;
using namespace Guikachu::Widgets;

GraffitiProperties::GraffitiProperties (Graffiti *res)
{
    using namespace Gtk;
    using namespace SigC;
    
    GUI::PropertyTable *proptable = new GUI::PropertyTable ();
    
    /* Resource ID */
    WidgetProperties::add_general_controls (res, *proptable);

    /* Separator */
    proptable->add_separator ();

    /* Position */
    WidgetProperties::add_position_controls (res, *proptable);
    
    property_editor = proptable;
}

GraffitiProperties::~GraffitiProperties ()
{
    delete property_editor;
}

Gtk::Widget* GraffitiProperties::get_editor ()
{
    return property_editor;
}

==> guikachu_1.4.0.orig.tar.gz: guikachu-1.4.0/src/form-editor/graffiti-prop.cc <==
//$Id: graffiti-prop.cc,v 1.12 2003/06/30 14:07:57 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "graffiti-prop.h"


#include "config.h"
#include <libgnome/libgnome.h>

#include "widgets/propertytable.h"

using namespace Guikachu::GUI::FormEditor;
using namespace Guikachu::Widgets;

GraffitiProperties::GraffitiProperties (Graffiti *res):
    WidgetProperties (res)
{
    using namespace Gtk;
    using namespace SigC;
    
    GUI::PropertyTable *proptable = new GUI::PropertyTable ();
    
    /* Resource ID */
    add_general_controls (*proptable);

    /* Separator */
    proptable->add_separator ();

    /* Position */
    add_position_controls (*proptable);
    
    property_editor = proptable;
}

GraffitiProperties::~GraffitiProperties ()
{
    delete property_editor;
}

Gtk::Widget* GraffitiProperties::get_editor ()
{
    return property_editor;
}
